# Security Policy

## Supported Versions

Only the latest release receives security fixes.

| Version | Supported |
|---------|-----------|
| 0.7.x (latest) | Yes |
| < 0.7 | No |

## Reporting a Vulnerability

Email: mo@boxlink.net

Please do not open a public GitHub issue for security vulnerabilities.

Include:
- Description of the vulnerability
- Steps to reproduce
- Potential impact

You will receive a response within 48 hours.
